@@ -99,6 +99,7 @@ components.feasts_x13arimaseats <- function(object, ...){
       logarithmic = "*",
       multiplicative = "*",
       additive = "+",
+      "auto-mode" = if(fit$udg["aictrans"] == "Log(y)") "*" else "+",
       "pseudo-add" = "pseudo-add"
     )
     y_expr <- if(op == "pseudo-add") {
@@ -435,11 +436,14 @@ model_sum.feasts_x13arimaseats <- function(x){
 #' }
 #'
 #' @examples
+#'
+#' \donttest{
 #' fit <- tsibbledata::aus_production %>%
 #'   model(X_13ARIMA_SEATS(Beer))
 #'
 #' report(fit)
 #' components(fit)
+#' }
 #'
 #' @seealso [seasonal::seas()]
 #'
